package com.supervision.pdfqaserver.dto;

import cn.hutool.core.util.StrUtil;
import com.supervision.pdfqaserver.domain.DomainMetadata;
import com.supervision.pdfqaserver.domain.ErAttribute;
import lombok.Data;

import java.util.ArrayList;
import java.util.List;

/**
 * 领域元数据DTO
 */
@Data
public class DomainMetadataDTO {

    private String id;

    /**
     * 意图摘要
     */
    private String intentDigest;


    /**
     * 领域分类id
     */
    private String domainCategoryId;

    /**
     * 头节点类型
     */
    private String sourceType;

    private List<ERAttributeDTO> sourceAttributes = new ArrayList<>();

    /**
     * 关系
     */
    private String relation;

    private List<ERAttributeDTO> relationAttributes = new ArrayList<>();

    /**
     * 尾节点类型
     */
    private String targetType;

    private List<ERAttributeDTO> targetAttributes = new ArrayList<>();

    /**
     * 数据来源：0=手动录入，1=系统自动
     */
    private String generationType;


    public DomainMetadataDTO() {
    }

    public DomainMetadata toDomainMetadata() {
        DomainMetadata domainMetadata = new DomainMetadata();
        domainMetadata.setId(this.id);
        domainMetadata.setSourceType(this.sourceType);
        domainMetadata.setTargetType(this.targetType);
        domainMetadata.setRelation(this.relation);
        domainMetadata.setDomainCategoryId(this.domainCategoryId);
        domainMetadata.setGenerationType(this.generationType);
        return domainMetadata;
    }

    public DomainMetadataDTO(DomainMetadata domainMetadata,List<ErAttribute> erAttributes) {
        this.id = domainMetadata.getId();
       this.domainCategoryId = domainMetadata.getDomainCategoryId();
       this.sourceType = domainMetadata.getSourceType();
       this.relation = domainMetadata.getRelation();
       this.targetType = domainMetadata.getTargetType();
       this.generationType = domainMetadata.getGenerationType();

        for (ErAttribute erAttribute : erAttributes) {
            if (StrUtil.equals(erAttribute.getDomainMetadataId(),this.id)){
                if(StrUtil.equals(erAttribute.getErType(),"1")){
                    // 节点数据
                    if (StrUtil.equals(erAttribute.getAttrName(),this.sourceType)) {
                        this.sourceAttributes.add(new ERAttributeDTO(erAttribute));
                    }
                    if (StrUtil.equals(erAttribute.getAttrName(),this.targetType)) {
                        this.targetAttributes.add(new ERAttributeDTO(erAttribute));
                    }
                }else {
                    if (StrUtil.equals(erAttribute.getAttrName(),this.relation)) {
                        this.relationAttributes.add(new ERAttributeDTO(erAttribute));
                    }
                }
            }
        }
    }

}
