package com.supervision.pdfqaserver.dto;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.supervision.pdfqaserver.domain.ChineseEnglishWords;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import java.util.*;

/**
 * 实体关系抽取
 */
@Slf4j
@Data
public class EREDTO {

    private List<EntityExtractionDTO> entities = new ArrayList<>();

    private List<RelationExtractionDTO> relations = new ArrayList<>();

    public EREDTO() {
    }

    public static EREDTO fromTextJson(String json,String truncationId) {
        EREDTO eredto = new EREDTO();
        JSONObject jsonObject = JSONObject.parseObject(json);
        JSONArray nodes = jsonObject.getJSONArray("nodes");
        JSONArray relations = jsonObject.getJSONArray("relations");
        List<EntityExtractionDTO> entities = new ArrayList<>();
        List<RelationExtractionDTO> relationsList = new ArrayList<>();
        if (CollUtil.isNotEmpty(nodes)){
            for (Object node : nodes) {
                JSONObject nodeJson = (JSONObject) node;
                String name = nodeJson.getString("name");
                String type = nodeJson.getString("type");
                if (StrUtil.hasBlank(name,type)){
                    continue;
                }
                name = StrUtil.trim(name);
                type = StrUtil.trim(type);
                JSONObject attributes = nodeJson.getJSONObject("attributes");
                List<TruncationERAttributeDTO> truncationErAttributeDTOS = new ArrayList<>();
                if (CollUtil.isNotEmpty(attributes)){
                    for (String key : attributes.keySet()) {
                        Object value = attributes.get(key);
                        String valueString = attributes.getString(key);
                        TruncationERAttributeDTO truncationErAttributeDTO = new TruncationERAttributeDTO(key, valueString, value instanceof Number?"1":"0");
                        truncationErAttributeDTO.setAssociationType("0");
                        truncationErAttributeDTOS.add(truncationErAttributeDTO);
                    }
                }
                EntityExtractionDTO entityExtraction = new EntityExtractionDTO(truncationId,type,name, truncationErAttributeDTOS);
                entities.add(entityExtraction);
            }
        }
        if (CollUtil.isNotEmpty(relations)){
            for (Object relation : relations) {
                JSONObject relationJson = (JSONObject) relation;
                String source = relationJson.getString("source");
                String target = relationJson.getString("target");
                String type = relationJson.getString("type");
                JSONObject attributes = relationJson.getJSONObject("attributes");
                List<TruncationERAttributeDTO> truncationErAttributeDTOS = new ArrayList<>();
                if (CollUtil.isNotEmpty(attributes)){
                    for (String key : attributes.keySet()) {
                        if (StrUtil.isBlank(key)){
                            continue;
                        }
                        Object value = attributes.get(key);
                        if (value instanceof String){
                            if (StrUtil.isBlank((String) value)){
                                continue;
                            }
                            value = StrUtil.trim((String) value);
                        }
                        String valueString = attributes.getString(key);
                        TruncationERAttributeDTO truncationErAttributeDTO = new TruncationERAttributeDTO(key, valueString, value instanceof Number?"1":"0");
                        truncationErAttributeDTO.setAssociationType("1");
                        truncationErAttributeDTOS.add(truncationErAttributeDTO);
                    }
                }
                if (StrUtil.isBlank(source) || StrUtil.isBlank(target)){
                    log.warn("truncationId:{} relation:{} 关系中source or target is empty",truncationId,relationJson);
                    continue;
                }
                final String sourceTrim = StrUtil.trim(source);
                Optional<EntityExtractionDTO> sourceTypeOpt = entities.stream().filter(e -> StrUtil.equals(e.getName(), sourceTrim)).findFirst();
                if (sourceTypeOpt.isEmpty()){
                    log.warn("truncationId:{} relation:{} 关系中source在实体中不存在",truncationId,relationJson);
                    continue;
                }
                final String targetTrim = StrUtil.trim(target);
                Optional<EntityExtractionDTO> targetTypeOpt = entities.stream().filter(e -> StrUtil.equals(e.getName(), targetTrim)).findFirst();
                if (targetTypeOpt.isEmpty()){
                    log.warn("truncationId:{} relation:{} 关系中target在实体中不存在",truncationId,relationJson);
                    continue;
                }
                RelationExtractionDTO relationExtractionDTO = new RelationExtractionDTO(truncationId,source,
                        sourceTypeOpt.get().getEntity(),type,target,targetTypeOpt.get().getEntity(), truncationErAttributeDTOS);
                relationsList.add(relationExtractionDTO);
            }
        }
        eredto.setEntities(entities);
        eredto.setRelations(relationsList);
        return eredto;
    }

    public static EREDTO fromTableJson(String json,String truncationId) {

        EREDTO eredto = new EREDTO();
        JSONObject jsonObject = JSONObject.parseObject(json);
        JSONArray tables = jsonObject.getJSONArray("table_data");

        if (CollUtil.isEmpty(tables)){
            return eredto;
        }
       List<EntityExtractionDTO> entities = new ArrayList<>();
        for (Object table : tables) {
            JSONObject tableJson = (JSONObject) table;
            if (CollUtil.isEmpty(tableJson)){
                continue;
            }
            EntityExtractionDTO entityExtractionDTO = new EntityExtractionDTO();
            entityExtractionDTO.setEntity("行");
            // 避免表格行名重复
            entityExtractionDTO.setName("行-" +  RandomUtil.randomString(UUID.randomUUID().toString(), 10));
            entityExtractionDTO.setTruncationId(truncationId);
            List<TruncationERAttributeDTO> truncationErAttributeDTOS = new ArrayList<>();
            for (Map.Entry<String, Object> tableEntry : tableJson.entrySet()) {
                String key = tableEntry.getKey();
                if (StrUtil.isBlank(key)){
                    continue;
                }
                key = StrUtil.trim(key);
                Object value = tableEntry.getValue();
                if (value instanceof String){
                    if (StrUtil.isBlank(value.toString())){
                        continue;
                    }
                    value = StrUtil.trim((String) value);
                }
                TruncationERAttributeDTO truncationErAttributeDTO = new TruncationERAttributeDTO(key, value.toString(), value instanceof Number ? "1" : "0");
                truncationErAttributeDTOS.add(truncationErAttributeDTO);
            }
            entityExtractionDTO.setAttributes(truncationErAttributeDTOS);
            entities.add(entityExtractionDTO);
        }
        eredto.setEntities(entities);
        return eredto;
    }

    public void setEn(List<ChineseEnglishWords> wordsList) {
        if (CollUtil.isEmpty(wordsList)){
            return;
        }
        for (EntityExtractionDTO entity : entities) {
            String entityName = entity.getEntity();
            Optional<ChineseEnglishWords> first = wordsList.stream().filter(w -> StrUtil.equals(w.getChineseWord(), entityName)).findFirst();
            first.ifPresent(chineseEnglishWords -> entity.setEntityEn(chineseEnglishWords.getEnglishWord()));

            if (CollUtil.isNotEmpty(entity.getAttributes())){
                for (TruncationERAttributeDTO attribute : entity.getAttributes()) {
                    setAttributeEn(attribute, wordsList);
                }
            }
        }
        for (RelationExtractionDTO relation : relations) {
            String relationName = relation.getRelation();
            Optional<ChineseEnglishWords> first = wordsList.stream().filter(w -> StrUtil.equals(w.getChineseWord(), relationName)).findFirst();
            first.ifPresent(chineseEnglishWords -> relation.setRelationEn(chineseEnglishWords.getEnglishWord()));

            String sourceType = relation.getSourceType();
            Optional<ChineseEnglishWords> sourceTypeFirst = wordsList.stream().filter(w -> StrUtil.equals(w.getChineseWord(), sourceType)).findFirst();
            sourceTypeFirst.ifPresent(chineseEnglishWords -> relation.setSourceTypeEn(chineseEnglishWords.getEnglishWord()));

            String targetType = relation.getTargetType();
            Optional<ChineseEnglishWords> targetTypeFirst = wordsList.stream().filter(w -> StrUtil.equals(w.getChineseWord(), targetType)).findFirst();
            targetTypeFirst.ifPresent(chineseEnglishWords -> relation.setTargetTypeEn(chineseEnglishWords.getEnglishWord()));

            if (CollUtil.isNotEmpty(relation.getAttributes())){
                for (TruncationERAttributeDTO attribute : relation.getAttributes()) {
                    setAttributeEn(attribute, wordsList);
                }
            }
        }

    }

    private void setAttributeEn(TruncationERAttributeDTO attribute, List<ChineseEnglishWords> wordsList) {
        if (null == attribute || CollUtil.isEmpty(wordsList)){
            return;
        }
        String attributeName = attribute.getAttribute();
        Optional<ChineseEnglishWords> attributeFirst = wordsList.stream().filter(w -> StrUtil.equals(w.getChineseWord(), attributeName)).findFirst();
        attributeFirst.ifPresent(chineseEnglishWords -> attribute.setAttributeEn(chineseEnglishWords.getEnglishWord()));
    }
}
