package com.supervision.pdfqaserver.dto;

import com.supervision.pdfqaserver.domain.DomainMetadata;
import com.supervision.pdfqaserver.domain.TruncationRelationExtraction;
import lombok.Data;
import java.util.List;

/**
 * 关系抽取
 */
@Data
public class RelationExtractionDTO {

    private String id;

    private String truncationId;

    /**
     * 头节点数据
     */
    private String source;

    /**
     * 头节点类型
     */
    private String sourceType;

    private String sourceTypeEn;

    /**
     *关系
     */
    private String relation;

    private String relationEn;

    /**
     * 尾节点数据
     */
    private String target;

    /**
     * 尾节点类型
     */
    private String targetType;

    private String targetTypeEn;

    private List<TruncationERAttributeDTO> attributes;

    public RelationExtractionDTO() {
    }

    public RelationExtractionDTO(TruncationRelationExtraction relationExtraction) {
        this.id = relationExtraction.getId();
        this.truncationId = relationExtraction.getTruncationId();
        this.source = relationExtraction.getSource();
        this.sourceType = relationExtraction.getSourceType();
        this.relation = relationExtraction.getRelation();
        this.target = relationExtraction.getTarget();
        this.targetType = relationExtraction.getTargetType();
    }

    public RelationExtractionDTO(String truncationId, String source, String sourceType, String relation, String target, String targetType, List<TruncationERAttributeDTO> attributes) {
        this.truncationId = truncationId;
        this.source = source;
        this.relation = relation;
        this.target = target;
        this.attributes = attributes;
        this.sourceType = sourceType;
        this.targetType = targetType;
    }

    public TruncationRelationExtraction toTruncationRelationExtraction() {
        TruncationRelationExtraction truncationRelationExtraction = new TruncationRelationExtraction();
        truncationRelationExtraction.setTruncationId(this.truncationId);
        truncationRelationExtraction.setSource(this.source);
        truncationRelationExtraction.setSourceType(this.sourceType);
        truncationRelationExtraction.setRelation(this.relation);
        truncationRelationExtraction.setTarget(this.target);
        truncationRelationExtraction.setTargetType(this.targetType);
        return truncationRelationExtraction;
    }

    public DomainMetadata toDomainMetadata() {
        DomainMetadata domainMetadata = new DomainMetadata();
        domainMetadata.setSourceType(this.sourceType);
        domainMetadata.setRelation(this.relation);
        domainMetadata.setTargetType(this.targetType);
        return domainMetadata;
    }
}
