package com.supervision.pdfqaserver.dto;

import com.supervision.pdfqaserver.domain.DocumentTruncation;
import lombok.Data;

/**
 * 分段内容
 */
@Data
public class TruncateDTO {

    /**
     * 分段id
     */
    private String id;

    /**
     * 布局类型 0-文本 1-表格
     */
    private String layoutType;

    /**
     * 文档id(pdf_info表的id)
     */
    private Integer documentId;

    /**
     * 段落id pdf_analysis_output表的id
     */
    private Integer sectionId;

    /**
     * 表格标题
     */
    private String title;

    /**
     * 分段内容
     */
    private String content;


    public TruncateDTO() {
    }

    public TruncateDTO(DocumentDTO documentDTO) {
        this.documentId = Integer.parseInt(documentDTO.getId());
        this.sectionId = documentDTO.getSectionId();
        this.layoutType = documentDTO.getLayoutType().toString();
        this.title = documentDTO.getTitle();
        this.content = documentDTO.getContent();
    }

    public TruncateDTO(DocumentDTO documentDTO,String content) {
        this.documentId = Integer.parseInt(documentDTO.getId());
        this.sectionId = documentDTO.getSectionId();
        this.layoutType = documentDTO.getLayoutType().toString();
        this.title = documentDTO.getTitle();
        this.content = content;
    }

    public TruncateDTO(DocumentTruncation documentTruncation) {
        this.id = documentTruncation.getId();
        this.documentId = documentTruncation.getDocumentId();
        this.sectionId = documentTruncation.getSectionId();
        this.layoutType = documentTruncation.getLayoutType();
        this.title = documentTruncation.getTitle();
        this.content = documentTruncation.getContent();
    }

    public DocumentTruncation toDocumentTruncation() {
        DocumentTruncation truncation = new DocumentTruncation();
        truncation.setDocumentId(this.documentId);
        truncation.setSectionId(this.sectionId);
        truncation.setLayoutType(this.layoutType);
        truncation.setTitle(this.title);
        truncation.setContent(this.content);
        return truncation;
    }





}
