package com.supervision.pdfqaserver.service;

import com.supervision.pdfqaserver.constant.DocumentContentTypeEnum;
import com.supervision.pdfqaserver.dto.*;
import java.util.List;

/**
 * 三元组转换管道
 */
public interface TripleConversionPipeline {


    /**
     * 识别出PDF文档类型
     * @param pdfId 文档ID
     * @return DocumentContentTypeEnum 文档类型
     */
    DocumentContentTypeEnum makeOutPdfContentType(Integer pdfId);


    /**
     * 识别出PDF文档行业
     * @param pdfId 文档ID
     * @return 行业
     */
    String makeOutPdfIndustry(Integer pdfId);


    /**
     * 识别出truncate的意图,训练过程中使用
     * @param truncate 切分文档
     * @return String
     */
    List<String> makeOutTruncationIntent(TruncateDTO truncate);

    /**
     * 识别出truncate的意图,非训练过程中使用
     * @param truncate 切分文档
     * @param intents 意图列表
     * @return
     */

    List<IntentDTO> makeOutTruncationIntent(TruncateDTO truncate, List<IntentDTO> intents);


    /**
     * 识别出truncate的领域元数据, 训练时使用
     * @param truncate 切分文档
     * @return DomainMetadataDTO
     */
    List<DomainMetadataDTO> makeOutDomainMetadata(TruncateDTO truncate,List<String> intents);


    /**
     * 实体关系抽取
     * @param truncateDTO 切分文档
     * @param intents 意图
     * @return
     */
    EREDTO doEre(TruncateDTO truncateDTO,List<IntentDTO> intents);

    /**
     * 切分文档
     * @param documents 文档列表
     * @return
     */
    List<TruncateDTO> sliceDocuments(List<DocumentDTO> documents);


    /**
     * 实体关系抽取
     * @param truncateDTO 切分文档
     * @return
     */
    EREDTO doEre(TruncateDTO truncateDTO);

    /**
     * 分类表格是否为描述型表格
     * @param content 文档内容
     * @return true-描述型表格 false-非描述型表格
     */
    Boolean classify(String content);


    /**
     * 提取表格标题
     * @param content 文档内容
     * @return
     */
    TableTitleDTO extractTableTitle(String content);

    /**
     * 合并实体关系抽取结果
     * @param eredtoList 实体关系抽取结果列表
     * @return
     */
    List<EREDTO> mergeEreResults(List<EREDTO> eredtoList);

}
