package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.DocumentTruncation;
import com.supervision.pdfqaserver.dto.TruncateDTO;
import com.supervision.pdfqaserver.service.DocumentTruncationService;
import com.supervision.pdfqaserver.mapper.DocumentTruncationMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
* @author Administrator
* @description 针对表【document_truncation(文档切分表)】的数据库操作Service实现
* @createDate 2025-04-27 11:45:24
*/
@Service
public class DocumentTruncationServiceImpl extends ServiceImpl<DocumentTruncationMapper, DocumentTruncation>
    implements DocumentTruncationService{

    @Override
    public void batchSave(List<TruncateDTO> truncateDTOS) {
        if (CollUtil.isEmpty(truncateDTOS)){
            return;
        }
        for (TruncateDTO truncateDTO : truncateDTOS) {
            DocumentTruncation documentTruncation = truncateDTO.toDocumentTruncation();
            this.save(documentTruncation);
            truncateDTO.setId(documentTruncation.getId());
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteByDocumentId(String documentId) {
        if (StrUtil.isEmpty(documentId)){
            return;
        }
        this.lambdaUpdate().eq(DocumentTruncation::getDocumentId, documentId).remove();
    }

    @Override
    public void deleteByDocumentIds(List<String> documentIds) {
        if (CollUtil.isEmpty(documentIds)){
            return;
        }
        this.lambdaUpdate().in(DocumentTruncation::getDocumentId, documentIds).remove();
    }

    @Override
    public List<DocumentTruncation> queryByDocumentId(String documentId) {
        return this.lambdaQuery().eq(DocumentTruncation::getDocumentId, documentId).list();
    }

    @Override
    public List<DocumentTruncation> queryByDocumentIds(List<String> documentIds) {
        if (CollUtil.isEmpty(documentIds)){
            return new ArrayList<>();
        }
        return this.lambdaQuery().in(DocumentTruncation::getDocumentId, documentIds).list();
    }

    @Override
    public List<DocumentTruncation> queryNotERETruncate(List<String> documentIds) {
        return null;
    }

    @Override
    public List<DocumentTruncation> listByPdfId(Integer pdfId) {
        return super.baseMapper.listByPdfId(pdfId);
    }
}




