package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.IntentionDomainMetadata;
import com.supervision.pdfqaserver.service.IntentionDomainMetadataService;
import com.supervision.pdfqaserver.mapper.IntentionDomainMetadataMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import java.util.ArrayList;
import java.util.List;

/**
* @author Administrator
* @description 针对表【intention_domain_metadata】的数据库操作Service实现
* @createDate 2025-05-14 15:23:54
*/
@Service
public class IntentionDomainMetadataServiceImpl extends ServiceImpl<IntentionDomainMetadataMapper, IntentionDomainMetadata>
    implements IntentionDomainMetadataService{

    @Override
    public List<IntentionDomainMetadata> listByIntentionId(String intentionId) {
        if (StrUtil.isEmpty(intentionId)){
            return new ArrayList<>();
        }
        return this.lambdaQuery().eq(IntentionDomainMetadata::getIntentionId, intentionId).list();
    }

    @Override
    public List<IntentionDomainMetadata> listByIntentionIds(List<String> intentionIds) {
        if (CollUtil.isEmpty(intentionIds)){
            return new ArrayList<>();
        }
        return this.lambdaQuery().in(IntentionDomainMetadata::getIntentionId, intentionIds).list();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void batchSaveIfAbsent(String intentionId, List<String> metadataIds) {
        if (CollUtil.isEmpty(metadataIds)){
            return;
        }
        Assert.notEmpty(intentionId, "意图ID不能为空");

        List<IntentionDomainMetadata> intentMetadataList = this.listByIntentionId(intentionId);
        List<String> list = metadataIds.stream().filter(metadataId -> intentMetadataList.stream().noneMatch(item -> item.getDomainMetadataId().equals(metadataId))).toList();
        if (CollUtil.isNotEmpty(list)){
            List<IntentionDomainMetadata> doms = new ArrayList<>();
            for (String metadataId : list) {
                IntentionDomainMetadata idm = new IntentionDomainMetadata();
                idm.setIntentionId(intentionId);
                idm.setDomainMetadataId(metadataId);
                doms.add(idm);
            }
            this.saveBatch(doms);
       }
    }
}




