package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.lang.Assert;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.PdfAnalysisOutput;
import com.supervision.pdfqaserver.service.PdfAnalysisOutputService;
import com.supervision.pdfqaserver.mapper.PdfAnalysisOutputMapper;
import org.springframework.stereotype.Service;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
* @author Administrator
* @description 针对表【pdf_analysis_output】的数据库操作Service实现
* @createDate 2025-04-27 11:45:24
*/
@Service
public class PdfAnalysisOutputServiceImpl extends ServiceImpl<PdfAnalysisOutputMapper, PdfAnalysisOutput>
    implements PdfAnalysisOutputService{

    @Override
    public List<PdfAnalysisOutput> queryByPdfId(Integer pdfId) {
        Assert.notNull(pdfId, "pdfId不能为空");

        return super.lambdaQuery().eq(PdfAnalysisOutput::getPdfId, pdfId).list();
    }

    @Override
    public String queryByPdfIdAndLimit(Integer pdfId, Integer limit) {
        if (null == limit || limit <= 0) {
            return null;
        }
        List<PdfAnalysisOutput> pdfAnalysisOutputs = this.queryByPdfId(pdfId);
        // 截取前300个字符
        String fullText = pdfAnalysisOutputs.stream().sorted(
                Comparator.comparingInt(PdfAnalysisOutput::getPageNo)
                        .thenComparingInt(PdfAnalysisOutput::getDisplayOrder)
        ).map(PdfAnalysisOutput::getContent).collect(Collectors.joining());
        return fullText.substring(0, Math.min(limit, fullText.length()));
    }
}




