package com.supervision.pdfqaserver.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.PdfInfo;
import com.supervision.pdfqaserver.service.PdfInfoService;
import com.supervision.pdfqaserver.mapper.PdfInfoMapper;
import org.springframework.stereotype.Service;
import java.time.LocalDateTime;
import java.util.List;

/**
* @author Administrator
* @description 针对表【pdf_info(pdf信息)】的数据库操作Service实现
* @createDate 2025-04-27 11:45:24
*/
@Service
public class PdfInfoServiceImpl extends ServiceImpl<PdfInfoMapper, PdfInfo>
    implements PdfInfoService{

    @Override
    public void pdfToGraphStart(Integer pdfId) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getProcessStatus, 4)
                .set(PdfInfo::getExtractionStartTime, LocalDateTime.now())
                .update();
    }

    @Override
    public void pdfToGraphComplete(Integer pdfId) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getProcessStatus, 5)
                .set(PdfInfo::getExtractionEndTime, LocalDateTime.now())
                .update();
    }

    @Override
    public void pdfToGraphFail(Integer pdfId) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getProcessStatus, 6)
                .set(PdfInfo::getExtractionEndTime, LocalDateTime.now())
                .update();
    }

    @Override
    public List<PdfInfo> listNeedGenerateGraph(Integer limit) {
        return this.lambdaQuery().eq(PdfInfo::getProcessStatus, 2)
                .last("limit " + limit)
                .list();
    }

    @Override
    public PdfInfo getByPdfId(Integer pdfId) {
        return this.getById(pdfId);
    }

    @Override
    public void updateContentType(Integer pdfId, String contentType) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getContentType, contentType)
                .update();
    }

    @Override
    public void updateCategory(Integer pdfId, String category) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getDomainCategoryId, category)
                .update();
    }

    @Override
    public void pdfTrainStart(Integer pdfId) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getTrainStatus, 0)
                .set(PdfInfo::getTrainStartTime, LocalDateTime.now())
                .update();
    }

    @Override
    public void pdfTrainComplete(Integer pdfId) {

        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getTrainStatus, 1)
                .set(PdfInfo::getTrainEndTime, LocalDateTime.now())
                .update();
    }

    @Override
    public void pdfTrainFail(Integer pdfId) {
        this.lambdaUpdate().eq(PdfInfo::getId, pdfId)
                .set(PdfInfo::getTrainStatus, 2)
                .set(PdfInfo::getTrainEndTime, LocalDateTime.now())
                .update();
    }


}




