package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.TruncationErAttribute;
import com.supervision.pdfqaserver.domain.TruncationRelationExtraction;
import com.supervision.pdfqaserver.dto.TruncationERAttributeDTO;
import com.supervision.pdfqaserver.dto.RelationExtractionDTO;
import com.supervision.pdfqaserver.service.TruncationErAttributeService;
import com.supervision.pdfqaserver.service.TruncationRelationExtractionService;
import com.supervision.pdfqaserver.mapper.TruncationRelationExtractionMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import java.util.List;

/**
* @author Administrator
* @description 针对表【truncation_relation_extraction(片段关系抽取)】的数据库操作Service实现
* @createDate 2025-04-27 11:45:24
*/
@Slf4j
@Service
@RequiredArgsConstructor
public class TruncationRelationExtractionServiceImpl extends ServiceImpl<TruncationRelationExtractionMapper, TruncationRelationExtraction>
    implements TruncationRelationExtractionService{

    private final TruncationErAttributeService truncationErAttributeService;
    @Override
    public void saveERE(List<RelationExtractionDTO> relations) {
        if (CollUtil.isEmpty(relations)){
            return;
        }

        for (RelationExtractionDTO relation : relations) {
            TruncationRelationExtraction re = relation.toTruncationRelationExtraction();
            this.save(re);
            if (CollUtil.isEmpty(relation.getAttributes())){
                continue;
            }
            for (TruncationERAttributeDTO attribute : relation.getAttributes()) {
                TruncationErAttribute era = attribute.toTruncationErAttribute();
                era.setTerId(re.getId());
                truncationErAttributeService.save(era);
            }
        }
    }

    @Override
    public void deleteByTruncationId(String truncationId) {
        if (StrUtil.isEmpty(truncationId)){
            return;
        }
        List<TruncationRelationExtraction> truncationRelationExtractions = this.lambdaQuery()
                .eq(TruncationRelationExtraction::getTruncationId, truncationId).list();
        if (CollUtil.isNotEmpty(truncationRelationExtractions)) {
            List<String> terIds = truncationRelationExtractions.stream().map(TruncationRelationExtraction::getId).toList();
            truncationErAttributeService.deleteByTerIds(terIds);
            this.lambdaUpdate().eq(TruncationRelationExtraction::getTruncationId, truncationId).remove();
        }
    }

    @Override
    public List<TruncationRelationExtraction> queryByTruncationIds(List<String> documentIds) {
        if (CollUtil.isEmpty(documentIds)){
            return new ArrayList<>();
        }
        return this.lambdaQuery().in(TruncationRelationExtraction::getTruncationId, documentIds).list();
    }
}




