package com.supervision.pdfqaserver;

import com.supervision.pdfqaserver.constant.DocumentContentTypeEnum;
import com.supervision.pdfqaserver.dto.EREDTO;
import com.supervision.pdfqaserver.dto.IntentDTO;
import com.supervision.pdfqaserver.dto.TruncateDTO;
import com.supervision.pdfqaserver.service.ChinesEsToEnglishGenerator;
import com.supervision.pdfqaserver.service.KnowledgeGraphService;
import com.supervision.pdfqaserver.service.TripleConversionPipeline;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.Test;
import org.neo4j.driver.*;
import org.neo4j.driver.Record;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import static org.neo4j.driver.Values.parameters;

@Slf4j
@SpringBootTest
class PdfQaServerApplicationTests {

    @Autowired
    private KnowledgeGraphService knowledgeGraphService;
    @Test
    void generateGraphTest() {
        knowledgeGraphService.generateGraph("40");
        log.info("finish...");
    }

    @Test
    void testGenerateGraph2() {
        List<EREDTO> eredtos = knowledgeGraphService.listPdfEREDTO("17");

        knowledgeGraphService.generateGraph(eredtos);
        log.info("finish...");
    }

    @Autowired
    private Driver driver;

    /**
     * 测试保存或更新节点
     */
    @Test
    void testSaveOrUpdateEntityNode() {

        List<Long> longs = saveOrUpdateRelation(7838L, 7940L, "REL_TYPE", true, false, Map.of("name", "test1"));
        System.out.println(longs);
    }
    public void saveOrUpdateEntityNode(String label, String uniqueKey, Map<String, Object> properties) {

        try (Session session = driver.session()) {
            // MERGE语句确保唯一性
            String query = String.format(
                    "MERGE (n:%s {%s: $uniqueValue}) " +
                            "SET n += $properties " +
                            "RETURN id(n)  as id",
                    label, uniqueKey);

            Result result = session.run(query, parameters("uniqueValue", properties.get(uniqueKey), "properties", properties));


            if (result.hasNext()) {
                Record next = result.next();
                Value value = next.get("id");
                long aLong = value.asLong();
                System.out.printf("已处理 %s 节点: %s%n", label, next.keys());
            }
        }
    }

    private List<Long> saveOrUpdateRelation(Long sourceId, Long targetId, String relationType,
                                            boolean leftDirection, boolean rightDirection, Map<String, Object> relation) {

        try (Session session = driver.session()) {
            // MERGE关系
            String query = "MATCH (a) WHERE id(a) = $sourceId " +
                    "MATCH (b) WHERE id(b) = $targetId " +
                    "MERGE (a)%s-[r:" + relationType + "]-%s(b) " +
                    "SET r += $properties " +
                    "RETURN id(r) as id";

            String format = String.format(query,
                    leftDirection ? "<" : "",
                    rightDirection ? ">" : "");

            Result result = session.run(format,
                    parameters("sourceId", sourceId, "targetId", targetId, "properties", relation));

            return result.stream().map(record -> record.get("id").asLong()).collect(Collectors.toList());
        }
    }
    @Autowired
    private  ChinesEsToEnglishGenerator chinesEsToEnglishGenerator;
    @Test
    void testChinesEsToEnglishGenerator() {
        String chinese = "你好";
        String english = chinesEsToEnglishGenerator.generate(chinese);
        System.out.println("翻译结果: " + english);
    }

    @Autowired
    TripleConversionPipeline tripleConversionPipeline;
    @Test
    void testChinesEsToEnglishGenerator2() {
        String s = """
                 |                                          | 项<br>日  |  |      | 附注 | 2023年12月31日        | 2023年1月1日          |
                 |------------------------------------------|---------|--|------|----|--------------------|--------------------|
                 | 流动资产:                                    |         |  |      |    |                    |                    |
                 | 货币资金                                     |         |  | 六、1  |    | 4,879,272,436.13   | 20,493,232,077.05  |
                """;
        Boolean classify = tripleConversionPipeline.classify(s);
        System.out.println(classify);
    }

    @Test
    void makeOutPdfContentTypeTest() {
        DocumentContentTypeEnum documentContentTypeEnum = tripleConversionPipeline.makeOutPdfContentType(5);
        System.out.println(documentContentTypeEnum);
    }

    @Test
    void makeOutPdfIndustryTest() {
        String industry = tripleConversionPipeline.makeOutPdfIndustry(5);
        System.out.println(industry);
    }

    @Test
    void makeOutTruncationIntentTest() {
        TruncateDTO truncateDTO = new TruncateDTO();
        truncateDTO.setContent("# 2、同时按照境外会计准则与按照中国会计准则披露的财务报告中净利润和净资产差异情况 \n" +
                "\n" +
                "□适用 回不适用 ");
        List<String> strings = tripleConversionPipeline.makeOutTruncationIntent(truncateDTO);
        System.out.println(strings);
    }

    @Test
    void makeOutTruncationIntentTest2() {
        TruncateDTO truncateDTO = new TruncateDTO();
        truncateDTO.setContent("# 2、同时按照境外会计准则与按照中国会计准则披露的财务报告中净利润和净资产差异情况 \n" +
                "\n" +
                "□适用 回不适用 ");
        IntentDTO intentDTO = new IntentDTO();
        intentDTO.setDigest("财务报告差异分析");
        List<IntentDTO> strings = tripleConversionPipeline.makeOutTruncationIntent(truncateDTO,List.of(intentDTO));
        System.out.println(strings);
    }


}
